@@ -1,8 +1,8 @@
 import os
 import uuid
 
-ZeromqConnection = "tcp://localhost:5555"
-# ZeromqConnection = "ipc:///tmp/idontexist.socket"
+GrpcHost = "127.0.0.1"
+GrpcPort = 5601
 
 # style like azure pipeline enviroment variables.
 ArtifactStagingDirectory = "/a"
@@ -14,8 +14,11 @@ ArtifactOutputDirectory = "/a/output"
 ArtifactArgumentsDirectory = "/a/arguments"
 
 WorkerIdentity = str(uuid.uuid4())
+SlideId = str(uuid.uuid4())
+TaskId = str(uuid.uuid4())
 
-ZeromqConnection = os.getenv('ZEROMQCONNECTION', ZeromqConnection)
+GrpcHost = os.getenv('GrpcHost', GrpcHost)
+GrpcPort = int(os.getenv('GrpcPort', str(GrpcPort)))
 ArtifactStagingDirectory = os.getenv(
     'ArtifactStagingDirectory', ArtifactStagingDirectory)
 BinariesDirectory = os.getenv(
@@ -36,3 +39,10 @@ ArtifactArgumentsDirectory = os.getenv(
 )
 
 WorkerIdentity = os.getenv('JobId', WorkerIdentity)
+TaskId = os.getenv('TaskId', TaskId)
+SlideId = os.getenv('SlideId', SlideId)
+
+RedisHost = os.getenv('RedisHost', '127.0.0.1')
+RedisPort = os.getenv('RedisPort', 6379)
+
+SlideCloudUrl = 'http://private.intemedic.com:6002'
